@@ -754,6 +754,14 @@ function previewTemplate($id, $adminid = 0, $text = '', $footer = '')
         $template = str_replace($logoInstance, '?page=image&amp;id='.$logoImageId.$logoSize, $template);
     }
 
+    $orgName = getConfig('organisation_name');
+    if ($orgName === '' || $orgName === null) {
+        // If organisation name is not set, show [ORGANISATION_NAME] placeholder
+        $template = str_ireplace('[ORGANISATION_NAME]', '[ORGANISATION_NAME]', $template);
+    } else {
+        $template = str_ireplace('[ORGANISATION_NAME]', $orgName, $template);
+    }
+
     if (!EMAILTEXTCREDITS) {
         $template = str_ireplace('[SIGNATURE]',
             '<img src="?page=image&amp;id='.$poweredImageId.'" width="70" height="30" />', $template);
@@ -1385,6 +1393,12 @@ function parseQueryString($str)
 
 function cleanUrl($url, $disallowed_params = array('PHPSESSID'))
 {
+    // process url only if it contains a disallowed parameter
+    $pattern = sprintf('/(%s)=/', implode('|', $disallowed_params));
+
+    if (!preg_match($pattern, $url)) {
+        return htmlspecialchars_decode($url);
+    }
     $parsed = @parse_url($url);
     $params = array();
     if (empty($parsed['query'])) {
@@ -1479,12 +1493,16 @@ function addSubscriberStatistics($item, $amount, $list = 0)
     }
 }
 
+
 /**
  * Insert a draft campaign for use with the Invite plugin
+ * @param null|int $forcedOwnerId
+ * @return bool|mysqli_result
+ * @throws Exception
  * @todo Make the campaign content translatable
  * @todo Add Campaign Meta Title to clarify purpose of this draft
  */
-function addInviteCampaign() {
+function addInviteCampaign($forcedOwnerId = null) {
 
     $message =
 '<p>Hi [FIRST NAME%%there], remember us? You first signed up for our email newsletter on&nbsp;[ENTERED] &ndash; please click here to confirm you&#39;re happy to continue receiving our messages:</p>
@@ -1502,7 +1520,11 @@ function addInviteCampaign() {
     $inviteMessage = addslashes($message);
     $inviteMessageSubject = "Do you want to continue receiving our messages?";
     $uuid = uuid::generate(4);
-    $ownerid = $_SESSION['logindetails']['id'];
+    if ( $forcedOwnerId !== null) {
+        $ownerid = $forcedOwnerId;
+    } else {
+        $ownerid = $_SESSION['logindetails']['id'];
+    }
     $footer = sql_escape(getConfig('messagefooter'));
     $result = Sql_query("insert into {$GLOBALS['tables']['message']} (uuid,subject,message,entered, status, owner, footer, sendformat) values(\"$uuid\",\"$inviteMessageSubject\",\"$inviteMessage\",now(),\"draft\",\"$ownerid\",\"$footer\",\"invite\" )");
 
@@ -1661,7 +1683,7 @@ function resetMessageStatistics($messageid = 0)
             $messageid));
         Sql_Query(sprintf('delete from %s where messageid = %d', $GLOBALS['tables']['usermessage'], $messageid));
         Sql_Query(sprintf('delete from %s where messageid = %d', $GLOBALS['tables']['user_message_view'], $messageid));
-        Sql_Query(sprintf('update %s set viewed = 0 where messageid = %d', $GLOBALS['tables']['message'], $messageid));
+        Sql_Query(sprintf('update %s set viewed = 0 where id = %d', $GLOBALS['tables']['message'], $messageid));
     }
 }
 
@@ -2047,7 +2069,7 @@ function subscribeToAnnouncementsForm($emailAddress = '')
         .'<h3>'.s('Sign up to receive news and updates about phpList ').'</h3>'
         .s('Make sure you are updated with new security and feature release announcements (fewer than one message per month)').
         '<script type="text/javascript">var pleaseEnter = "'.strip_tags($emailAddress).'";</script> '.
-        '<script type="text/javascript" src="../js/jquery-1.5.2.min.js"></script>
+        '<script type="text/javascript" src="../js/jquery-3.3.1.min.js"></script>
 <script type="text/javascript" src="../js/phplist-subscribe-0.3.min.js"></script>
 <div id="phplistsubscriberesult"></div> <form action="https://announce.hosted.phplist.com/lists/?p=subscribe&id=3" method="post" id="phplistsubscribeform">
 <input type="text" name="email" value="" id="emailaddress" />
@@ -2142,6 +2164,34 @@ function parseLogoPlaceholders($content)
     return $content;
 }
 
+/**
+ * Parse [CONTACT] as HTML placeholder for VCard
+ * @param $content
+ * @return mixed
+ */
+function parseVCardHTMLPlaceholder($content) {
+    preg_match_all('/\[CONTACT\:?(\d+)?\]/i', $content, $contactInstances);
+    foreach ($contactInstances[0] as $index => $contactInstance) {
+        $content = str_ireplace($contactInstance, '<a href="'.htmlentities(getConfig('vcardurl')).'">'.$GLOBALS['strContactMessage'].'</a>', $content);
+    }
+
+    return $content;
+}
+
+/**
+ * Parse [CONTACT] as Text placeholder for VCard
+ * @param $content
+ * @return mixed
+ */
+function parseVCardTextPlaceholder($content) {
+    preg_match_all('/\[CONTACT\:?(\d+)?\]/i', $content, $contactInstances);
+    foreach ($contactInstances[0] as $index => $contactInstance) {
+        $content = str_ireplace($contactInstance, $GLOBALS['strContactMessage'].' '.htmlentities(getConfig('vcardurl')), $content);
+    }
+
+    return $content;
+}
+
 /**
  * Loop through a multi-dimensional array, check a particular child array
  * key equals desired value, and return a new multi-dimensional array of those
@@ -2229,7 +2279,7 @@ function asyncLoadContent($url)
 {
     return '<script type="text/javascript">
         var loadMessage = \'' .sjs('Please wait, your request is being processed. Do not refresh this page.').'\';
-        var loadMessages = new Array(); 
+        var loadMessages = new Array();
         loadMessages[30] = \'' .sjs('Still loading').'\';
         loadMessages[90] = \'' .sjs('It may seem to take a while, but there is a lot of data to crunch<br/>if you have a lot of subscribers and campaigns').'\';
         loadMessages[150] = \'' .sjs('It should be soon now, your page content is almost here.').'\';
