@@ -85,29 +85,6 @@ if (isset($_GET['uid']) && $_GET['uid']) {
     $userid = $req[1];
     $userpassword = $req[2];
     $emailcheck = $req[3];
-} elseif (isset($_GET['email'])) {
-    $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where email = "%s"',
-        $tables['user'], $_GET['email']));
-    $id = $req[0];
-    $userid = $req[1];
-    $userpassword = $req[2];
-    $emailcheck = $req[3];
-} elseif (isset($_REQUEST['unsubscribeemail'])) {
-    $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where email = "%s"',
-        $tables['user'], sql_escape($_REQUEST['unsubscribeemail'])));
-    $id = $req[0];
-    $userid = $req[1];
-    $userpassword = $req[2];
-    $emailcheck = $req[3];
-    /*
-    } elseif ($_SESSION["userloggedin"] && $_SESSION["userid"]) {
-      $req = Sql_Fetch_Row_Query(sprintf('select subscribepage,id,password,email from %s where id = %d',
-        $tables["user"],$_SESSION["userid"]));
-      $id = $req[0];
-      $userid = $req[1];
-      $userpassword = $req[2];
-      $emailcheck = $req[3];
-    */
 } else {
     $userid = '';
     $userpassword = '';
@@ -290,7 +267,15 @@ if ($login_required && empty($_SESSION['userloggedin']) && !$canlogin) {
                     }
                     exit;
                 } else {
+                    // we failed to subscribe the user; send an error back to
+                    // the ajax client
+
                     echo 'FAIL';
+
+                    // thow an exception so the http status code is a 500
+                    // Internal Server Error, easily caught by jquery.ajax()
+                    throw new Exception( "Error: Subscribe attempt failed!" );
+
                 }
                 break;
             case 'preferences':
@@ -320,6 +305,9 @@ if ($login_required && empty($_SESSION['userloggedin']) && !$canlogin) {
             case 'confirm':
                 print ConfirmPage($id);
                 break;
+            case 'vcard':
+                print downloadvCard();
+                break;
             //0013076: Blacklisting posibility for unknown users
             case 'donotsend':
             case 'blacklist':
@@ -343,7 +331,7 @@ if ($login_required && empty($_SESSION['userloggedin']) && !$canlogin) {
         while ($row = Sql_Fetch_Array($req)) {
             $intro = Sql_Fetch_Row_Query(sprintf('select data from %s where id = %d and name = "intro"',
                 $tables['subscribepage_data'], $row['id']));
-            echo $intro[0];
+            echo stripslashes($intro[0]);
             if (SHOW_SUBSCRIBELINK) {
                 printf('<p><a href="'.getConfig('subscribeurl').'&id=%d">%s</a></p>', $row['id'],
                     strip_tags(stripslashes($row['title'])));
@@ -372,7 +360,7 @@ if ($login_required && empty($_SESSION['userloggedin']) && !$canlogin) {
                 return '&#'.ord($m[0]).';';
             }
             , 'mailto:'.getConfig('admin_address')).
-        '">'.s('Contact the administrator').'</a></p>';
+        '">'.$GLOBALS['strContactAdmin'].'</a></p>';
     echo $PoweredBy;
     echo $pagedata['footer'];
 }
@@ -393,7 +381,7 @@ function LoginPage($id, $userid, $email = '', $msg = '')
 
     $html .= formStart('name="loginform"');
     $html .= '<table border=0>';
-    $html .= '<tr><td>'.$GLOBALS['strEmail'].'</td><td><input type=text name="email" value="'.$email.'" size="30"></td></tr>';
+    $html .= '<tr><td>'.$GLOBALS['strEmail'].'</td><td><input type=text name="email" value="'.$email.'" size="30" autofocus></td></tr>';
     $html .= '<tr><td>'.$GLOBALS['strPassword'].'</td><td><input type="password" name="password" value="'.$_POST['password'].'" size="30"></td></tr>';
     $html .= '</table>';
     $html .= '<p><input type=submit name="login" value="'.$GLOBALS['strLogin'].'"></p>';
@@ -480,7 +468,7 @@ function checkform()
     if ($GLOBALS['pagedata']['emaildoubleentry'] == 'yes') {
         $html .= '
   if (! compareEmail()) {
-    alert("Email addresses you entered do not match");
+    alert("' .str_replace('"', '\"', $GLOBALS['strEmailsNoMatch']).'");
 
     return false;
   }';
@@ -488,7 +476,7 @@ function checkform()
 
     $html .= '
   if (! checkEmail()) {
-    alert("Email addresses you entered is not valid");
+    alert("' .str_replace('"', '\"', $GLOBALS['strEmailNotValid']).'");
 
     return false;
   }';
@@ -548,6 +536,16 @@ function checkEmail()
     return $html;
 }
 
+function downloadvCard(){
+
+    require 'admin/vCard.php';
+    $vCard = new vCard();
+    $vCard-> setOrg(getConfig('organisation_name'));
+    $vCard-> setEmail(getConfig('message_from_address'));
+    $vCard-> setUrl('http://'.getConfig('website'));
+    $vCard->createVCard();
+}
+
 function subscribePage($id)
 {
     //  return subscribePage2($id);
@@ -727,7 +725,7 @@ function confirmPage($id)
         while ($row = Sql_fetch_array($req)) {
             array_push($subscriptions, $row['id']);
             $lists .= "\n *".stripslashes($row['name']);
-            $html .= '<li class="list">'.stripslashes($row['name']).'<div class="listdescription">'.stripslashes($row['description']).'</div></li>';
+            $html .= '<li class="list"><b>'.stripslashes($row['name']).'</b><div class="listdescription">'.stripslashes($row['description']).'</div></li>';
         }
         $html .= '</ul>';
         if ($blacklisted) {
@@ -757,7 +755,7 @@ function confirmPage($id)
                 addSubscriberStatistics('confirmation', 1);
             }
         } else {
-            $html = $GLOBALS['strAlreadyConfirmed'];
+            $html .= $GLOBALS['strAlreadyConfirmed'];
         }
         $_SESSION['subscriberConfirmed'][$userdata['email']] = time();
         $info = $GLOBALS['strConfirmInfo'];
